STRING_AGG: Date add function to be passed along to SQL

View source: R/aou_sql_functions.R

STRING_AGGR Documentation

Date add function to be passed along to SQL

Description

Date add function to be passed along to SQL

Usage

STRING_AGG(...)

Arguments

...

additional arguments passed to dbplyr SQL

Value

Internal, passed along to dbplyr SQL.


allofus documentation built on July 4, 2024, 9:09 a.m.