| aou_cohort_example | R Documentation |
A data frame containing tables and columns in the All of Us Controlled Tier Dataset v7 CDR Data Dictionary (C2022Q4R9) found here: https://docs.google.com/spreadsheets/d/1XLVq84LLd0VZMioF2sPwyiaPw3EFp5c8o1CTWGPH-Yc/edit#gid=1815943286. Note that the column 'value_source_value' has been manually added as it is missing from the data dictionary.
aou_cohort_example
aou_cohort_example
Cohort definition object
SQL query for cohort definition
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.